==> paperless-20201130.1241.tar: paperless-20201130.1241/org-paperless.el <==
;;; org-paperless.el --- org-mode integration for paperless

;; Copyright (c) 2017 Anthony Green

;; This file is NOT part of GNU Emacs.

;;; License:

;; Redistribution and use in source and binary forms, with or without
;; modification, are permitted provided that the following conditions
;; are met:
;;
;; 1. Redistributions of source code must retain the above copyright
;;    notice, this list of conditions and the following disclaimer.
;; 2. Redistributions in binary form must reproduce the above copyright
;;    notice, this list of conditions and the following disclaimer in the
;;    documentation and/or other materials provided with the distribution.
;; 3. The name of the author may not be used to endorse or promote products
;;    derived from this software without specific prior written permission.
;;
;; THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
;; IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
;; OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
;; IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
;; INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
;; NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES ; LOSS OF USE,
;; DATA, OR PROFITS ; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
;; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
;; (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
;; THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

;;; Code:

(require 'org)

(org-link-set-parameters "paperless" :store #'org-paperless-store-link)

(defun org-paperless-store-link ()
  "Store a link to the filed document"
  (cond
   ((eq major-mode 'paperless-mode)
    (let ((vctr (cadr (assoc (tabulated-list-get-id) paperless--table-contents))))
      (cond
       ((not (= (length (elt vctr 2)) 0))
	(org-store-link-props
	 :type "file"
	 :link (concat (elt vctr 2) "/" (elt vctr 1))))
       (t (error "Set destination directory before storing link")))))))

(provide 'org-paperless)

==> paperless-20240130.1048.tar: paperless-20240130.1048/org-paperless.el <==
;;; org-paperless.el --- org-mode integration for paperless -*- lexical-binding: t; -*-

;; Copyright (c) 2017, 2023, 2024 Anthony Green

;; This file is NOT part of GNU Emacs.

;;; Commentary:

;; Store links to filed documents.

;;; License:

;; Redistribution and use in source and binary forms, with or without
;; modification, are permitted provided that the following conditions
;; are met:
;;
;; 1. Redistributions of source code must retain the above copyright
;;    notice, this list of conditions and the following disclaimer.
;; 2. Redistributions in binary form must reproduce the above copyright
;;    notice, this list of conditions and the following disclaimer in the
;;    documentation and/or other materials provided with the distribution.
;; 3. The name of the author may not be used to endorse or promote products
;;    derived from this software without specific prior written permission.
;;
;; THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
;; IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
;; OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
;; IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
;; INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
;; NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES ; LOSS OF USE,
;; DATA, OR PROFITS ; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
;; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
;; (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
;; THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

;;; Code:

(require 'org)
(require 'paperless)

(defvar paperless--table-contents)

(org-link-set-parameters "paperless" :store #'paperless--org-paperless-store-link)

(defun paperless--org-paperless-store-link ()
  "Store a link to the filed document."
  (cond
   ((eq major-mode 'paperless-mode)
    (let ((vctr (cadr (assoc (tabulated-list-get-id) paperless--table-contents))))
      (cond
       ((not (= (length (elt vctr 2)) 0))
	(org-link-store-props
	 :type "file"
	 :link (concat (elt vctr 2) "/" (elt vctr 1))))
       (t (error "Set destination directory before storing link")))))))

(provide 'org-paperless)

;;; org-paperless.el ends here
